C          TITLE: CORRELATOR, A PROGRAM FOR INTERACTIVE 
C                 LITHOSTRATIGRAPHIC CORRELATION OF
C                 WIRELINE LOGS, VERSION 5.2 
C
C          AUTHORS: RICARDO A. OLEA
C                   ROBERT J. SAMPSON
C
C          LAST UPDATE : DECEMBER 2003
C
C          PURPOSE: PERFORM LITHOLOGICAL CORRELATIONS BETWEEN
C                   PAIRS OF WELLS. FOR EACH WELL, A SHALE
C                   LOG AND A CORRELATION LOG ARE REQUIRED,
C                   LIKE A SPONTANEOUS POTENTIAL AND A
C                   RESISTIVITY LOG, FOR INSTANCE.
C
C          HARDWARE REQUIREMENTS:
C                   UNIX SYSTEM FOR THE PROCESSING AND CALCOMP
C                   OR ANY PRINTER OR PLOTTER CAPABLE OF
C                   PROCESSING POTSCRIPT CODE FOR THE PURPOSE
C                   OF PREPARING HARDCOPIES OF RESULTS. 
C
C          SUBROUTINES REQUIRED:
C                   NAME IN PARENTHESIS DENOTES THE MODULE
C                   WHERE THE ROUTINE IS.
C
C                               ADDLOG(WELLDB)
C                               ADIPTM(DIP)
C                               ADIDXX(SECT)
C                               ADWELL(WELLDB)
C                               AGETTX(MENU)
C                               AGETIN(MENU)
C                               AGETRL(MENU)
C                               AGETST(MENU)
C                               AINPUT(MENU)
C                               ANHMOTIF1(SHALLE)
C                               ANHMOTIF2(SHALLE)
C                               ANHMOTIF3(SHALLE)
C                               ANHMOTIF4(SHALLE)
C                               ANHMOTIF5(PPTSPE)
C                               ANHMOTIF6(PPTSPE)
C                               ANMOD2(TCS_SUN)
C                               ANMODE(TCS_SUN)
C                               APEDIP(DIP)
C                               ARROWS(EXPERT)
C                               ASCOR (EXPERT)
C                               ASTRAC(ULOGS)
C                               AVECOR(EXPERT)
C                               AVEDIP(EXPERT)
C                               BANT01(EXPERT)
C                               BANT02(EXPERT)
C                               BANT04(EXPERT)
C                               BANT05(EXPERT)
C                               BANT07(EXPERT)
C                               BANT09(EXPERT)
C                               BANT10(EXPERT)
C                               BANT11(EXPERT)
C                               BANT16(EXPERT)
C                               BANT18(EXPERT)
C                               BANT19(EXPERT)
C                               BANT20(EXPERT)
C                               BANT21(EXPERT)
C                               BANT23(EXPERT)
C                               BARPLT(SORTIN)
C                               BEDDING(SHALLE)
C                               BBUNDL(EXPERT)
C                               BEDBOT(WEIN)
C                               BEDTOP(WEIN)
C                               BLOTIT(PPTSPE)
C                               BNSTAT(EXPERT)
C                               BUNABO(EXPERT)
C                               BUNBEL(EXPERT)
C                               BUSY(TCS_SUN)
C                               BXBOUN(DEFILE)
C                               CAQCOR(PRNT)
C                               CCCLEV(CCSINT)
C                               CENWID(DEFILE)
C                               CCEINT(CCEINT)
C                               CHALKMOTIF(SHALLE)
C                               CHKCFL(OPEN)
C                               CHKIFLT(FINDTR)
C                               CHKOLF(OPEN)
C                               CHKOLITHO(PRNT)
C                               CHKOTY(OPEN)
C                               CHKSC(PRNT)
C                               CLIP  (ULOGS)
C                               CLOSEA(FINDTR)
C                               CLOSEB(FINDTR)
C                               CLLOGS(ULOGS)
C                               COFIL(OTHER)
C                               COLCRS(WEIN)
C                               COLORPOR(GMP_SUN)
C                               COLORSCH(GMP_SUN)
C                               COLSET(WEIN)
C                               CORCOE(OTHER)
C                               CORLEN(WEIN)
C                               CORRXX(CORRDB)
C                               COSHAL(OTHER)
C                               CREATETOOLS(OTHER)
C                               CROCO (EXPERT)
C                               CROSCO (EXPERT)
C                               DATAFS(WELLDB)
C                               DATLAB(OTHER)
C                               DEFILE(DEFILE)
C                               DELETC(SORTIN)
C                               DIAGDOWN(SHALLE)
C                               DIAGUP(SHALLE)
C                               DISCO (DISCO)
C                               DISCOR(WEIN)
C                               DMMENU(GMENU)
C                               DNORTH(DIP)
C                               DRAWA(TCS_SUN)
C                               DRAWCV(OTHER)
C                               DRAWFS(PLTCOR)
C                               DRWLOG(PPTSPE)
C                               DTITLE(PPTSPE)
C                               DWBOX (OTHER)
C                               DWINDO(TCS_SUN)
C                               EDITCO(EXPERT)
C                               EDLOG(WELLDB)
C                               EDWELL(WELLDB)
C                               ELCO  (EXPERT)
C                               EMBEDD(EXPERT)
C                               EQLINE(PLTCOR)
C                               ERSTXT(TCS_SUN)
C                               EXPERT(EXPERT)
C                               EXPLAINLITH(PPTSPE)
C                               EXTCOR(EXPERT)
C                               EXTREM(WELLDB)
C                               FAUFIL(PLTCOR)
C                               FAULIN(SECT)
C                               FAULT(EXPERT)
C                               FCLITH(GMP_SUN)
C                               FDCOIN(EXPERT)
C                               FINDCP(CORRDB)
C                               FINDTR(FINDTR)
C                               FINISH(MENU)
C                               FINTL(SECT)
C                               FINTR(SECT)
C                               FMISSA(FINDTR)
C                               FMISSAML(FINDTR)
C                               FMISSB(FINDTR)
C                               FMISSBML(FINDTR)
C                               FOOTBAR(PPTSPE)
C                               GAMMA(ANALYS)
C                               GETALX(MENU)
C                               GETSPE(DEFILE)
C                               GETWEL(WELLDB)
C                               GEXTRD(OTHER)
C                               GEXTRE(OTHER)
C                               GMPDRW(GMP_SUN)
C                               GMPDSH(GMP_SUN)
C                               GMPFIN(GMP_SUN)
C                               GMPINI(GMP_SUN)
C                               GMPLCR(GMP_SUN)
C                               GMPMOV(GMP_SUN)
C                               GMPNUM(GMP_SUN)
C                               GMPOIL(GMP_SUN)
C                               GMPREA(GMP_SUN)
C                               GMPTXT(GMP_SUN)
C                               GRMODE(TCS_SUN)
C                               GRMOD2(TCS_SUN)
C                               GSTXFP(GMP_SUN)
C                               GTEXTC(TCS_SUN)
C                               GTEXTS(TCS_SUN)
C                               GTEXTX(TCS_SUN)
C                               GTXTIN(TCS_SUN)
C                               GTXTRJ(TCS_SUN)
C                               GTXTRL(TCS_SUN)
C                               GWSOIL(GMENU)
C                               HEADIN(OTHER)
C                               HEADNG(OTHER)
C                               HORSCALE(PPTSPE)
C                               IDATE(OPEN)
C                               INCOFI(CORRDB)
C                               INCORL(FINDTR)
C                               INCORR(FINDTR)
C                               INCFRW(FINDTR)
C                               INDEXM(DIP)
C                               INITT(TCS_SUN)
C                               INTERF(PLTCOR)
C                               JUMP  (EXPERT)
C                               KNOWBS(DISCO)
C                               LABELX(OTHER)
C                               LABELY(OTHER)
C                               LABEYD(OTHER)
C                               LABGRA(REGDIF)
C                               LEGEND(PPTSPE)
C                               LEGCOL(PPTSPE)
C                               LEGENDANH(PPTSPE)
C                               LEGENDCHALK(PPTSPE)
C                               LEGENDCOAL(PPTSPE)
C                               LEGENDDOL(PPTSPE)
C                               LEGENDGRAN(PPTSPE)
C                               LEGENDLS(PPTSPE)
C                               LEGENDSALT(PPTSPE)
C                               LEGENDSAND(PPTSPE)
C                               LEGENDSHALE(PPTSPE)
C                               LEGENDUNRES(PPTSPE)
C                               LGAMMA(ANALYS)
C                               LGSLAB(PLTCOR)
C                               LITHANNOT(PRNT)
C                               LINIBX(PLTCOR)
C                               LINPAR(PLTCOR)
C                               LINTSP(PLTCOR)
C                               LITH2(SECT)
C                               LITHCOAL(SHALLE)
C                               LITHCHALK(SHALLE)
C                               LITHDOL(SHALLE)
C                               LITHLEGEND(PPTSPE)
C                               LITHLIMEST(SHALLE)
C                               LITHOANOT(PRNT)
C                               LITHOPARAM(SHALLE)
C                               LITHOS(SECT)
C                               LITHSALT(SHALLE)
C                               LITHSAND(SHALLE)
C                               LITHSHALE(SHALLE)
C                               LITYPE(GMP_SUN)
C                               LOGO  (MENU)
C                               LOGSLA(OTHER)
C                               LOGVALUE(SHALLE)
C                               LOSEMI(ANALYS)
C                               LOSSS(EXPERT)
C                               LPCFSE(SECT)
C                               LTHEAD(PRYNT)
C                               LTRACN(FINDTR)
C                               MACOFI(CORRDB)
C                               MAINCM(MENU)
C                               MARFIL(ULOGS)
C                               MARROW(TCS_SUN)
C                               MATRIX(REGDIF)
C                               MCLINE(PLTCOR)
C                               MCLINE2(PLTCOR)
C                               MDRAWS(DEFILE)
C                               MENUAN(MENU)
C                               MENUCD(MENU)
C                               MENUCF(MENU)
C                               MENUFM(MENU)
C                               MENUGI(MENU)
C                               MENUSP(MENU)
C                               METRICBAR(PPTSPE)
C                               MILEBAR(PPTSPE)
C                               MISSEL(FINDTR)
C                               MISSER(FINDTR)
C                               MNMODE(TCS_SUN)
C                               MOVEA(TCS_SUN)
C                               MOVPEN(OTHER)
C                               MOVEPN(PPTSPE)
C                               MNMODE(TCS_SUN)
C                               NEWTRACL(FINDTR)
C                               NEWTRACR(PRNT)
C                               NSHALE(WELE)
C                               OPANAL(ANALYS)
C                               OPCOBS(OTHERS)
C                               OPCOIN(CCEINT)
C                               OPCOLE(CCSINT)
C                               OPDAFI(OTHER)
C                               OPDELE(SORTIN)
C                               OPELCO(EXPERT)
C                               OPEND (OPEN)
C                               OPENP (OPEN)
C                               OPENT (OPEN)
C                               OPFAFI(PLTCOR)
C                               OPFAUL(EXPERT)
C                               OPLITHOANOT(SHALLE)
C                               OPMAFI(ULOGS)
C                               OPPLOT(ULOGS)
C                               OPPRNP(PRNT)
C                               OPPRNT(PRNT)
C                               OPPRWE(WELLDB)
C                               OPSEMI(ANALYS)
C                               OPSHAL(SHALLE)
C                               OPSOFI(OTHER)
C                               OPSTRAC(ULOGS)
C                               OPSPEC(DEFILE)
C                               OPWELE(WELE)
C                               OVERLP(PRNT)
C                               PCMPTW(DEFILE)
C                               PENSET(GMP_SUN)
C                               PERSIS(PRNT)
C                               PERSXX(SECT)
C                               PLDATE(GMP)
C                               PLLOGS(ULOGS)
C                               PLODIT(DIP)
C                               PLORD (REGDIF)
C                               PLOTIN(DEFILE)
C                               PLRES (OTHER)
C                               PLTBOX(PLTCOR)
C                               PLTBSUR(PLTCOR)
C                               PLTCOR(PLTCOR)
C                               PLTDIP(DIP)
C                               PLTFAU(SECT)
C                               PLTSPE(OTHER)
C                               POGEOR(WEIN)
C                               POROSCALE(GMP_SUN)
C                               PPTSPE(PPTSPE)
C                               PRBUND(EXPERT)
C                               PRDAFI(OTHER)
C                               PRINTD(OTHER)
c                               PRITRA(PRNT)
C                               PRLITHOANOT(SHALLE)
C                               PRNPXX(PRNT)
C                               PRNTIN(PRNT)
C                               PRNTXX(PRNT)
C                               PRSOFI(OTHER)
C                               PRSPEC(DEFILE)
C                               PRTRHD(PRNT)
C                               PRWELL(WELLDB)
C                               PRYNT(PRYNT)
C                               PRYNTC(SORTIN)
C                               PRYNTP(SORTIN)
C                               PS_NEWPEN(PS)
C                               PSHADW(PLTCOR)
C                               RCPHDR(CORRDB)
C                               RDELCO(CORRDB)
C                               READAT(DEFILE)
C                               REALL (WELLDB)
C                               REALOG(WELLDB)
C                               REACOLITH(PRNT)
C                               REDATU(DEFILE)
C                               REDCPI(CORRDB)
C                               REDCPR(CORRDB)
C                               REETRA(PRNT)
C                               REFAUL(SECT)
C                               REGDIF(REGDIF)
C                               REGRES(REGDIF)
C                               REQUIRED(LCOR)
C                               RETKEY(MENU)
C                               RETREC(REGDIF)
C                               RINITT(TCS_SUN)
C                               RLTFL (ULOGS)
C                               RP4510(T4510)
C                               RPDAFI(OTHER)
C                               RPDATA(WELLDB)
C                               RPFAFI(PLTCOR)
C                               RPINCO(CORRDB)
C                               RPMAFI(ULOGS)
C                               RPPF(DEFILE)
C                               RPPRTP(SORTIN)
C                               RPPRNP(PRNT)
C                               RPPRNT(PRNT)
C                               RPPTIN(PRNT)
C                               RPSCOL(ULOGS)
C                               RPSECT(DEFILE)
C                               RPTRAC(SECT)
C                               RPSOFI(OTHER)
C                               RPSORT(SORTIN)
C                               RPSPEC(DEFILE)
C                               RPWELL(WELLDB)
C                               RTLOGS(ULOGS)
C                               RTRACIN(PRNT)
C                               RWELLH(WELLDB)
C                               SAVCOR(CORRDB)
C                               SCHED(PRNT)
C                               SCHOLD(TCS_SUN)
C                               SECTXX(SECT)
C                               SELTCP(CORRDB)
C                               SEMIVA(ANALYS)
C                               SETREJ(EXPERT)
C                               SHADBL(WELE)
C                               SHADIF(SHALLE)
C                               SHADLG(OTHER)
C                               SHADOW(OTHER)
C                               SHALED(WELE)
C                               SHOWCT(OTHER)
C                               SHWCUT(OTHER)
C                               SLED  (REGDIF)
C                               SLINDX(TCS_SUN)
C                               SLHARD(T4510)
C                               SNGL  (SORTIN)
C                               SNGLX(SORTIN)
C                               SORTCD(CORRDB)
C                               SORTIN(SORTIN)
C                               SPBALI(OTHER)
C                               SPTEST(OTHER)
C                               SSPBL (OTHER)
C                               SSPBL2(OTHER)
C                               STANDR(ULOGS)
C                               STENDE(ULOGS)
C                               STICKS(WEIN)
C                               STLOGS(ULOGS)
C                               STRACO(PRNT)
C                               SUMREG(REGDIF)
C                               T45PLT(T4510)
C                               T45CMD(T4510)
C                               T45CHR(T4510)
C                               T45INT(T4510)
C                               T45XY(T4510)
C                               TBELL (TCS_SUN)
C                               TDIDXX(SECT)
C                               TEKCHR(TCS_SUN)
C                               TEKCMD(TCS_SUN)
C                               TEKINT(TCS_SUN)
C                               TEKXY (TCS_SUN)
C                               TEQLIN(SECT)
C                               TKPLOT(TCS_SUN)
C                               TOOBIG(SECT)
C                               TOPBOT(DEFILE)
C                               TRACE2(PRNT)
C                               TRACIN(PRNT)
C                               TRACXX(SECT)
C                               TRUDIP(SECT)
C                               TWOINSIDE(SHALLE)
C                               TXTCLR(TCS_SUN)
C                               TXTCUR(TCS_SUN)
C                               UNCONF(PRNT)
C                               UNCONFWT(PRNT)
C                               UPDCDH(CORRDB)
C                               UPDWEL(WELLDB)
C                               VERYFY(EXPERT)
C                               WCLEGE(PPTSPE)
C                               WCORCO(WELE)
C                               WEINXX(WEIN)
C                               WELLDY(PPTSPE)
C                               WELEXX(WELE)
C                               WELLXX(WELLDB)
C                               WHEREN(DIP)
C                               WIDTH (OTHER)
C                               WKDONE(WEIN)
C                               WRTCPH(CORRDB)
C                               WRTCPI(CORRDB)
C                               WRTCPL(CORRDB)
C                               WRTCPR(CORRDB)
C                               WSCPCK(CORRDB)
C                               WSMETH(WELLDB)
C                               WSMENU(GMENU)
C                               X4510(T4510)
C                               XDRAWA(TCS_SUN)
C                               XDRAWC(GMENU)
C                               XENPLT(TCS_SUN)
C                               XINITT(TCS_SUN)
C                               XMOVEA(TCS_SUN)
C                               XMOVEC(GMENU)
C                               XSMENU(GMENU)
C                               XWINDO(TCS_SUN)
C                               XYPLT (REGDIF)
C                               XYTOSC(GMENU)
C                               ZPMENU(GMENU)
C
C
C          FUNCTIONS REQUIRED:
C                               BOMU  (ULOGS)
C                               CORTIEL (PLTCOR)
C                               DEPSEQ(EXPERT)
C                               GGROWTH(PLTCOR)
C                               GROWTH(PLTCOR)
C                               GROWTHDT(PLTCOR)
C                               FAUINT(FINDTR)
C                               FTDIP(DIP)
C                               MORF(ULOGS)
C                               PP2DEPTH(PRNT)
C                               SEQDEP(EXPERT)
C                               SIGNM(DIP)
C                               TITLEN(ULOGS)
C
C
C          DATA:
C               THE PROGRAM NEEDS WELL AND LOG INFORMATION.  REQUIRED
C               WELL DATA ARE:
C                  LOCATION IN CARTESIAN COORDINATES;
C                  ELEVATION FOR STARTING OF WELL READINGS, WHICH
C                     IS TYPICALLY THE KELLY BUSHING.  UNITS MAY
C                     BE DIFFERENT FROM THOSE FOR THE COORDINATES;
C                                    
C               A NAME AND A PRODUCTION SYMBOLS ARE ALSO CONVENIENT 
C               FOR THE PURPOSE OF IDENTIFICATION.  LOG READINGS MUST
C               BE SEPARATED BY BLANK SPACES, ACCORDING TO THE
C               STANDARDS OF LAS FORMAT.
C
C          EXECUTABLE PROGRAM:
C               TO PREPARE THE EXECUTABLE PROGRAM, TYPE:
C              
C                   make -f makefile.Linux
C
C          INTERNET REFERENCE:
C               FOR DETAILS ON PREPARATION OF DATA, PROCESSING, AND
C               DISPLAY OF RESULTS, SEE:
C    
C               OLEA, R. A. AND SAMPSON, R. J , 2004, USER'S MANUAL
C                    FOR CORRELATOR, VERSION 5.2: <HTTP://WWW.
C                    IAMG.ORG/CGEDITOR/INDEX.HTM>, 145 P.
C
C***********************************************************************
C
      PROGRAM LCOR
C
      INCLUDE 'log.inc'
C
C         VARIABLE DEFINITION.
C
C               WEIGHTED CORRELATION COEFFICIENT.
      REAL*4 CORRL(LOG_LENGTH)
C               PRINTING MATRIX IN POLYNOMIAL REGRESSION
      COMMON /DLOGSX/ D
        REAL*8 D(LOG_LENGTH,5)
C               WELL DATA FILE FLAG
        INTEGER*2 DATAFL
C               FLAG TO KEEP TRACK OF FIRST EXECUTION OF AN OPTION
C               INVOLVING THE SELECTION OF PAIRS OF WELLS TO CORRELATE.
      INTEGER*4 I1STIM(15)
      INTEGER*4 I1STIN / 15 /
C               FLAG TO KEEP TRACK OF FIRST EXECUTION OF AN OPTION NOT
C               INVOLVING THE SELECTION OF PAIRS OF WELLS TO CORRELATE.
      INTEGER*4 J1STIM(25)
      INTEGER*4 J1STIN / 25 /
      COMMON /SHADE/ KSHADR,KSHADM
C               SHADING COUNTING FOR MATCHING LOG.
             INTEGER*2 KSHADM(LOG_LENGTH)
C               SHADING COUNTING FOR REFERENCE LOG.
             INTEGER*2 KSHADR(LOG_LENGTH)
C               MENU SELECTION
      CHARACTER*2 MENUS
C               MAXIMUM NUMBER OF OBSERVATION FOR REGRESSION.
      INTEGER MXN/LOG_LENGTH/
C               NUMBER OF WELL IN THE WELL DATA FILE
      INTEGER*4 NUWELL
C
      COMMON /RLOGS/ RLOG1(LOG_LENGTH),IL1,RLOG3(LOG_LENGTH),IL3,
     X               RLOG2(LOG_LENGTH),IL2,RLOG4(LOG_LENGTH),IL4
C             SEQUENTIAL NUMBER FOR CORRELATION LOG ON REFERENCE WELL.
             INTEGER*4 LOG1
      COMMON /CODINC/ DINC
      COMMON /SHALEC/ NSHAL3,NSHAL4,SHALE
C            SHALE IN THE REFERENCE WELL, FRACTION 0-1.
             REAL*4 NSHAL3(LOG_LENGTH)
C            SHALE IN THE MATCHING WELL, FRACTION 0-1.
             REAL*4 NSHAL4(LOG_LENGTH)
C            SHALE DIFFERENCE.
             REAL*4 SHALE(LOG_LENGTH)
      COMMON /DIGS/ DIGS1,DIGS2
C               STARTING DEPTH FOR EACH DIGITIZED LOG.
             REAL*4 DIGS1
             REAL*4 DIGS2
      COMMON /BEDTB/BEDT,BEDB
C               ROCK UNIT BOTTOMS.
             INTEGER*2 BEDB(LOG_LENGTH)
C               ROCK UNIT TOPS.
             INTEGER*2 BEDT(LOG_LENGTH)
      COMMON /HEAD/   ID1,PSYMB1,LOG3,LOG1,DATUM1,NNCOR,
     X                ID2,PSYMB2,LOG4,LOG2,DATUM2,HDIST,
     X                DEPRMN,DEPRMX,DEPMMN,DEPMMX,
     X                SLG3MN,SLG3MX,CLG1MN,CLG1MX,
     X                SLG4MN,SLG4MX,CLG2MN,CLG2MX
C            PRODUCTION SYMBOL FOR REFERENCE WELL.
             INTEGER*4 PSYMB1
C            PRODUCTION SYMBOL FOR MATCHING WELL.
             INTEGER*4 PSYMB2
             REAL*4 DATUM1,DATUM2
      COMMON /OPENST/ OPENER
             LOGICAL OPENER
      COMMON /CHARH/   FYLES,DATUM,NAME1,NAME2
C            LOG DATA FILE NAME AND WELL DATA FILE
             CHARACTER*40 FYLES /'*????*'/
C               DATUM.
             CHARACTER*15 DATUM
C            REFERENCE WELL NAME.
             CHARACTER*20 NAME1
C            MATCHING WELL NAME.
             CHARACTER*20 NAME2
      COMMON /DRIFTSP/ SPPR,SPPM
      INTEGER*4 SPPR,SPPM
      COMMON /DIGZ12/  DIGZS1,DIGZS2
      COMMON /USCAL/   BOM,SCLSHL,SCLCOL
C               FLAG TO INDICATE BRITISH OR METRIC UNITS SYSTEM
             CHARACTER*1 BOM
C               FLAG TO DENOTE INCREASING DIRECTION IN SHALE LOG AXIS
             CHARACTER*1 SCLSHL
C               FLAG DENOTING INCREASING DIRECTION
C               IN THE CORRELATION LOG AXIS
             CHARACTER*1 SCLCOL
             DATA SCLSHL/'R'/,SCLCOL/'R'/
      COMMON /BOML/    BOML
C               LABEL DENOTING THE UNIT OF LENGTH.
              CHARACTER*4 BOML
      COMMON /LABELS/  IDSHAR,IDCORR,IDSHAM,IDCORM
C            MNEMONIC USED FOR SHALE LOG IDENTIFICATION
             CHARACTER*4 IDSHAM
             CHARACTER*4 IDSHAR
C            MNEMONIC USED FOR CORRELATION LOG IDENTIFICATION
             CHARACTER*4 IDCORM
             CHARACTER*4 IDCORR
      COMMON /PARACL/ RULB,FRLB,RUUB,FRUB
             REAL RULB,FRLB,RUUB,FRUB
      COMMON /CLIPAR/ RLMXC(4)
      COMMON /EXTRE/ RLMIN,RLMAX
C        LOG MINIMUM VALUES.
             REAL*4 RLMIN(4)
C        LOG MAXIMUM VALUES.
             REAL*4 RLMAX(4)
      COMMON /REAL4P/ XTOP,TTLSZ,ZLSZ,SYMSZ,WIDSZ,TKWD,HSCALE,VSCALE,
     1                DSWH,HWDIST,CSTART,CEND,PSSIZE,SHDIST
C            TRACK WIDTH, INCHES
             REAL*4 TKWD/1.20/
C            WELL PRODUCTION SYMBOL SIZE
             REAL*4 SYMSZ /0.25/
C            DEPTH SCALE WIDTH, INCHES.
             REAL*4 DSWH/0.54/
C            PRODUCTION SYMBOL SIZE, IN.
             REAL*4 PSSIZE/0.25/
C            WIDTH OF SPACE FOR ANNOTATIONS ON TOP OF LOGS
             REAL*4 XTOP/5.5/
      COMMON /YSTARTI/ YSTARTI
C            LEFTMOST PLOTTING START, IN.
             REAL*4 YSTARTI/1.0/
C
      COMMON /TICKMS/ TIC10,TIC50,TIC100
             REAL*4 TIC10/0.06/
             REAL*4 TIC50/0.10/
             REAL*4 TIC100/0.02/
C
      COMMON /COLOPT/ ICOLOR
             INTEGER*4 ICOLOR(6)/ 1,2,3,4,5,6/
C
      COMMON /UNITNM/ QTEKIN,QTEKOT,ITERMQ
      INTEGER QTEKIN,QTEKOT
      COMMON /PRINTU/ IPRNTU
      COMMON /PRINTC/ FYLEPR
             CHARACTER*40 FYLEPR
      COMMON /PLOTU/ IPLOTU,IPS_FLAG,IP_SIZE,P_MARGIN,IBW_COL
      COMMON /FYLPLO/ FYLPLO
             CHARACTER*40 FYLPLO
C
      COMMON /T4510A/ MXBUFR,IRPTR,MXLINE,NCOPYR,ICOPYR,ICOPYE
C
      COMMON /KEYBRD/ KEYB
C
      COMMON /WSOPTN/ WSFLAG
             LOGICAL WSFLAG
      DATA WSFLAG/.FALSE./
C
      COMMON /LITHFLAG/ NLITH, LITHFLAG, LITHLEGTOT
         INTEGER*4 NLITH /10/
         INTEGER*4 LITHFLAG(10)
      COMMON /FLAGWS/ FLAGWS
      LOGICAL FLAGWS
C
      include 'logfam.inc'
      DATA NFYLES/'FAMILY.NAM'/
      DATA SHLFAM/'SHALE'/,CORFAM/'RESISTIVITY'/
      DATA ISFAMX/0/,ICFAMX/0/
      DATA NFAMLY/0/
C
      include 'corrdb.inc'
      DATA CORRFN/'?*****?'/
      DATA NCCORR/-1/
      DATA NCCPTR/-1/
      DATA ICPREC/0/
C
      write(*,*) 'CORRELATOR'
      DO 101 I=1,J1STIN
      J1STIM(I)=0
  101 CONTINUE
      DO 102 I = 1,I1STIN
      I1STIM(I) = 0
  102 CONTINUE
      DATAFL = 0
      ID1=-1
      ID2=-1
C      IPRNTU=-1
C      FYLEPR=' '
      IPRNTU=71
      FYLEPR='PRINT.COR'
      J1STIM(4)=1
      FLAGWS = .TRUE.
      OPEN(IPRNTU,FILE=FYLEPR,STATUS='UNKNOWN',FORM='FORMATTED')
C      IPLOTU=-1
      IPLOTU   = 72
      IPS_FLAG = 0
      IP_SIZE  = 1
      P_MARGIN = 0.25
      IBW_COL  = 0
      FYLPLO = 'PLOT.COR'
      J1STIM(5) = 1
C
      ICOPYR=0
      ICOPYE=0
C
      QTEKIN=5
      QTEKOT=90
C
      OPEN(91,FILE='PR.TEST',FORM='FORMATTED',STATUS='UNKNOWN')
C
      CALL OPENT(31,NFYLES)
      CLOSE (31)
      IF (OPENER) THEN
         write(91,*) 'There is no FAMILY.NAM file.'
         CALL CREATETOOLS(NFYLES)
      ENDIF
C
C          OPEN OUTPUT UNIT.
C          =================
C
      ITERMQ=4
      CALL XINITT
      CALL XWINDO(0.0,132.0,0.0,66.0)
      CALL LOGO
C
C**********************************************************************
C
C            CORRELATOR MAIN MENU
C
C**********************************************************************
C
    1 CALL MAINCM(MENUS)
      IF (MENUS .EQ. 'FM') GO TO 8101
      IF (MENUS .EQ. 'CD') GO TO 8301
      IF (MENUS .EQ. 'CF') GO TO 8501
      IF (MENUS .EQ. 'GI') GO TO 8701
      IF (MENUS .EQ. 'AT') GO TO 8901
      IF (MENUS .EQ. 'SP') GO TO 9101
      IF (MENUS .EQ. 'ST') THEN
         CALL FINISH
         STOP
      END IF
      GO TO 1
C
C**********************************************************************
C
C         FILE MANAGEMENT
C
C**********************************************************************
C
 8101 CALL MENUFM(DATAFL,ID1,NCCPTR,MENUS)
      IF (MENUS .EQ. 'WB') GO TO 8121
      IF (MENUS .EQ. 'PW') GO TO 8123
      IF (DATAFL .GT. 0 ) THEN
         IF (MENUS .EQ. 'EW') GO TO 8125
         IF (MENUS .EQ. 'AL') GO TO 8127
         IF (MENUS .EQ. 'EL') GO TO 8129
         IF (MENUS .EQ. 'WS') GO TO 8141
         IF (MENUS .EQ. 'CB') GO TO 8151
         IF (MENUS .EQ. 'IC') GO TO 8153
         IF (MENUS .EQ. 'PC') GO TO 8154
         IF (MENUS .EQ. 'PA') GO TO 8169
         IF (MENUS .EQ. 'PL') GO TO 8171
         IF (MENUS .EQ. 'PM') GO TO 8173
         IF (MENUS .EQ. 'PD') GO TO 8175
         IF (MENUS .EQ. 'LC') GO TO 8182
         IF (MENUS .EQ. 'PF') GO TO 8192
         IF (NCCPTR .GT. 0) THEN
            IF (MENUS .EQ. 'PS') GO TO 8131
            IF (ID1 .GT. 0) THEN
               IF (MENUS .EQ. 'SO') GO TO 8155
               IF (MENUS .EQ. 'DL') GO TO 8157
               IF (MENUS .EQ. 'MC') GO TO 8161
              ENDIF
           ENDIF
        END IF
      IF (MENUS .EQ. 'RE') GO TO 1
      GO TO 8101
C
C                    WELL DATA FILE SELECTION
C                    ========================
C
 8121 CALL DATAFS(DATAFL,NUWELL,ID1OLD,1)
      DO 8122 I = 1,J1STIN
      IF (I. EQ. 4   .OR.  I .EQ. 5) GO TO 8122
      J1STIM(I) = 0
 8122 CONTINUE
      GO TO 8101
C
C                    PREPARATION OF WELL/LOG FILES.
C                    ==============================
C
 8123 CALL PRWELL(I1STIM(6),DATAFL)
      GO TO 8101
C
C                    EDIT  WELL INFORMATION.
C                    =======================
C
 8125 CALL EDWELL(NUWELL)
      GO TO 8101
C
C                    ADD LOGS TO A WELL.
C                    ===================
C
 8127 CALL ADDLOG(NUWELL)
      GO TO 8101
C
C                    EDIT LOG INFORMATION.
C                    =====================
C
 8129 CALL EDLOG(NUWELL)
      GO TO 8101
C
C                    PREPARATION OF SOURCE FILES.
C                    ============================
C
 8131 CALL PRSOFI(I1STIM(15))
      GO TO 8101
C                    SELECTION OF WELLS TO CORRELATE
C                    ==============================
C
 8141 CALL WELLXX(NUWELL)
      DO 8142 I = 1,I1STIN
      I1STIM(I) = 0
 8142 CONTINUE
      GO TO 8101
C                    SELECTION OF CORRELATION DATABASE FILE
C                    ======================================
C
 8151 CALL CORRXX
      GO TO 8101
C
C                    INITIALIZATION OF A CORRELATION  DATABASE FILE
C                    ==============================================
C
 8153 CALL INCOFI(J1STIM(9))
      GO TO 8101
C
C                    SORT A CORRELATION FILE
C                    =======================
C
 8155 CALL SORTIN
      GO TO 8101
C
C                    DELETE CORRELATIONS FROM A INTERPRETATION
C                    =========================================
C
 8157 CALL DELETC
      GO TO 8101
C
C                    PREPARATION OF A REFERENCE CORRELATION INTERPRETATION
C                    =====================================================
C
 8161 CALL MACOFI(J1STIM(14))
      GO TO 8101
C
C                    PREPARE A DRAWING SPECIFICATION FILE
C                    ====================================
C
 8154 CALL PRSPEC(J1STIM(17))
      GO TO 8101
C
C         PREPARATION OF FILE WITH STRATIGRAPHIC COLUMN SUBDIVISIONS
C         ==========================================================
C
 8169 CALL ASTRAC(J1STIM(21))
      GO TO 8101
C
C                    PREPARATION OF A LITHOLOGY FILE
C                    ===============================
C
 8171 CALL LITHOANOT(J1STIM(23))
      GO TO 8101
C
C                    PREPARATION OF A MARKER FILE
C                    ============================
C
 8173 CALL MARFIL(J1STIM(11))
      GO TO 8101
C
C                    PREPARE DATUM FILE.
C                    ===================
C
 8175 CALL PRDAFI(J1STIM(16))
      GO TO 8101
C
C        PREPARATION OF FILE FOR DISPLAY OF LITHOLOGY IN CROSS SECTION
C        =============================================================
C
 8182 CALL COFIL(J1STIM(25))
      GO TO 8101
C
C                    PREPARATION OF A FAULT FILE
C                    ===========================
C
 8192 CALL FAUFIL(J1STIM(13))
      GO TO 8101
C
C**********************************************************************
C
C         SETTINGS AND PREFERENCES
C
C**********************************************************************
C
 9101 CALL MENUSP(MENUS)
      IF (MENUS .EQ. 'PR') GO TO 9111
      IF (MENUS .EQ. 'PL') GO TO 9121
      IF (MENUS .EQ. 'SW') GO TO 9131
C      IF (MENUS .EQ. 'HC') GO TO 9141
      IF (MENUS .EQ. 'RE') GO TO 1
      GO TO 9101
C
C                    INITIALIZE A PRINTER FILE
C                    =========================
C
 9111 CALL PRNTIN(J1STIM(4))
      GO TO 9101
C
C                    INITIALIZE A PLOTTER FILE
C                    =========================
C
 9121 CALL PLOTIN(J1STIM(5))
      GO TO 9101
C
C                    SET WELL SELECTION METHOD
C                    =========================
C
 9131 CALL WSMETH
      GO TO 9101
C
C                    SELECT A 4510 FOR HARDCOPIES
C                    ============================
C
C 9141 CALL SLHARD
C      GO TO 9101
C
C**********************************************************************
C
C         CORRELATION DISPLAY
C
C**********************************************************************
C
 8301 CALL MENUCD(DATAFL,ID1,NCCPTR,MENUS)
      IF (MENUS .EQ. 'WB') GO TO 8311
      IF (DATAFL .GT. 0) THEN
         IF (MENUS .EQ. 'WS') GO TO 8313
         IF (MENUS .EQ. 'CB') GO TO 8315
         IF (NCCPTR .GT. 0) THEN
            IF (ID1 .GT. 0) THEN
               IF (MENUS .EQ. 'WL') GO TO 8321
               IF (MENUS .EQ. 'WD') GO TO 8331
               IF (MENUS .EQ. 'CP' .AND. IPRNTU .GT. 0) GO TO 8341
              ENDIF
           ENDIF
         IF (IPRNTU .GT. 0  .AND.  IPLOTU .GT. 0) THEN
            IF (MENUS .EQ. 'PC') GO TO 8351
           ENDIF
        ENDIF
      IF (MENUS .EQ. 'RE') GO TO 1
      GO TO 8301
C
C                    WELL DATA FILE SELECTION
C                    ========================
C
 8311 CALL DATAFS(DATAFL,NUWELL,ID1OLD,2)
      DO 8312 I = 1,J1STIN
      IF (I. EQ. 4   .OR.  I .EQ. 5) GO TO 8312
      J1STIM(I) = 0
 8312 CONTINUE
      GO TO 8301
C                    SELECTION OF WELLS TO CORRELATE
C                    ===============================
C
 8313 CALL WELLXX(NUWELL)
      DO 8314 I = 1,I1STIN
      I1STIM(I) = 0
 8314 CONTINUE
      GO TO 8301
C                    SELECTION OF CORRELATION DATABASE
C                    =================================
C
 8315 CALL CORRXX
      GO TO 8301
C
C                    SCREEN LIST A CORRELATION FILE
C                    ==============================
C
 8321 CALL PRYNTC
      GO TO 8301
C
C                    DISPLAY A CORRELATION FILE ON SCREEN
C                    ====================================
C
 8331 CALL DISCO(J1STIM(12))
      GO TO 8301
C
C                    COPY OF A CORRELATION FILE INTO A PRINTING FILE
C                    ===============================================
C
 8341 CALL PRYNTP
      GO TO 8301
C
C                    PRINT AND PLOT CORRELATIONS IN A CROSS SECTION
C                    ==============================================
C
 8351 IF (NCCPTR .GT. 0) THEN
         CALL SECTXX(J1STIM(8),NUWELL)
       ELSE
         CALL SECTXX(J1STIM(19),NUWELL)
      END IF
      ID1 = 0
      GO TO 8301
C
C**********************************************************************
C
C         CORRELATION FINDING
C
C**********************************************************************
C
 8501 CALL MENUCF(DATAFL,ID1,MENUS,NCCPTR)
      IF (MENUS .EQ. 'WB') GO TO 8511
      IF ( DATAFL .GT. 0 ) THEN
         IF (MENUS .EQ. 'WS') GO TO 8521
         IF (MENUS .EQ. 'CB') GO TO 8525
         IF ( ID1 .GT. 0 ) THEN
           IF (MENUS .EQ. 'SH') GO TO 8571
           IF (MENUS .EQ. 'CL') GO TO 8581
C           IF (MENUS .EQ. 'CI') GO TO 8591
           IF (NCCPTR .GE. 0) THEN
              IF (MENUS .EQ. 'WL') GO TO 8611
              IF (MENUS .EQ. 'WI') GO TO 8621
             ENDIF
           IF (NCCPTR .GT. 0) THEN  
              IF (MENUS .EQ. 'RD') GO TO 8631
             ENDIF
          ENDIF
       ENDIF
      IF (MENUS .EQ. 'RE') GO TO 1
      GO TO 8501
C
C                    WELL DATA FILE SELECTION
C                    ========================
C
 8511 CALL DATAFS(DATAFL,NUWELL,ID1OLD,3)
      DO 8512 I = 1,J1STIN
      IF (I. EQ. 4   .OR.  I .EQ. 5) GO TO 8512
      J1STIM(I) = 0
 8512 CONTINUE
      GO TO 8501
C                    SELECTION OF WELLS TO CORRELATE
C                    ==============================
C
 8521 CALL WELLXX(NUWELL)
      DO 8522 I = 1,I1STIN
      I1STIM(I) = 0
 8522 CONTINUE
      GO TO 8501
C                    SELECTION OF CORRELATION DATABASE
C                    =================================
C
 8525 CALL CORRXX
      GO TO 8501
C
C                    STANDARDIZED SHALE SIMILARITY FOR ONE LEVEL
C                    ===========================================
C
 8571 CALL SHADIF(I1STIM(9))
      GO TO 8501
C
C                    CROSS-CORRELATION COEFFICIENT FOR ONE LEVEL
C                    ===========================================
C
 8581 CALL CCCLEV(I1STIM(10))
      GO TO 8501
C                    CROSS-CORRELATION COEFFICIENTS OVER AN INTERVAL
C                    ===============================================
C
C 8591 CALL CCEINT(I1STIM(11))
C      GO TO 8501
C
C                    WEIGHTED CORRELATION COEFFICIENT FOR ONE LEVEL
C                    ==============================================
C
 8611 CALL WELEXX(I1STIM(5),KSHADR,KSHADM,CORRL)
      GO TO 8501
C
C                    WEIGHTED CORRELATION COEFFICIENT FOR AN INTERVAL
C                    ================================================
C
 8621 CALL WEINXX(I1STIM(12),ID1OLD,KSHADR,KSHADM,CORRL)
      GO TO 8501
C
C                    REGRESSION ON DIFFERENCE IN ELEVATION
C                    =====================================
C
 8631 CALL REGDIF(J1STIM(10),MXN)
      GO TO 8501
C
C**********************************************************************
C
C         GEOLOGIC INTERPRETATION
C
C**********************************************************************
C
 8701 CALL MENUGI(DATAFL,ID1,MENUS,NCCPTR)
      IF (MENUS .EQ. 'WB') GO TO 8711
      IF ( DATAFL .GT. 0 ) THEN
         IF (MENUS .EQ. 'WS') GO TO 8713
         IF (MENUS .EQ. 'CB') GO TO 8715
         IF (ID1 .GT. 0) THEN
            IF (MENUS .EQ. 'EC' .AND. NCCPTR .GT. 0) GO TO 8721
            IF (MENUS .EQ. 'DF') GO TO 8731
          ENDIF
         IF (IPRNTU .GT. 0) THEN
            IF (MENUS .EQ. 'TP' .AND. NCCPTR .GT. 0) GO TO 8741
            IF (MENUS .EQ. 'TM' .AND. NCCPTR .GT. 0) GO TO 8751
          ENDIF
         IF (IPLOTU .GT. 0) THEN
            IF (MENUS .EQ. 'AD' .AND. NCCPTR .GT. 0) GO TO 8756
            IF (MENUS .EQ. 'TD' .AND. NCCPTR .GT. 0) GO TO 8759
          ENDIF
         IF (IPRNTU .GT. 0  .AND.  IPLOTU .GT. 0) THEN
            IF (MENUS .EQ. 'LP' .AND. NCCPTR .GT. 0) GO TO 8761
            IF (MENUS .EQ. 'LM' .AND. NCCPTR .GT. 0) GO TO 8771
            IF (MENUS .EQ. 'PS' .AND. NCCPTR .GT. 0) GO TO 8781
            IF (MENUS .EQ. 'PO' .AND. NCCPTR .GT. 0) GO TO 8791
            IF (MENUS .EQ. 'LL' .AND. NCCPTR .GT. 0) GO TO 8796
          ENDIF
        ENDIF
      IF (MENUS .EQ. 'RE') GO TO 1
      GO TO 8701
C
C                    WELL DATA FILE SELECTION
C                    ========================
C
 8711 CALL DATAFS(DATAFL,NUWELL,ID1OLD,4)
      DO 8712 I = 1,J1STIN
      IF (I. EQ. 4   .OR.  I .EQ. 5) GO TO 8712
      J1STIM(I) = 0
 8712 CONTINUE
      GO TO 8701
C                    SELECTION OF WELLS
C                    ==================
C
 8713 CALL WELLXX(NUWELL)
      DO 8714 I = 1,I1STIN
      I1STIM(I) = 0
 8714 CONTINUE
      GO TO 8701
C                    SELECTION OF CORRELATION DATABASE
C                    =================================
C
 8715 CALL CORRXX
      GO TO 8701
C
C                   ELIMINATE CROSSING CORRELATIONS
C                   ===============================
C
 8721 CALL ELCO(J1STIM(2))
      GO TO 8701
C
C                   DETECT FAULTS
C                   =============
C
 8731 CALL FAULT(J1STIM(3))
      GO TO 8701
C
C                    PRINT PERSISTENT CORRELATIONS
C                    =============================
C
 8741 CALL PRNPXX(J1STIM(6))
      ID1 = 0
      GO TO 8701
C
C                    PRINT MARKERS
C                    =============
 8751 CALL PRNTXX(J1STIM(7))
      ID1 = 0
      GO TO 8701
C
C                    PLOT APPARENT DIP DIAGRAMS
C                    ==========================
 8756 CALL ADIDXX(J1STIM(18),NUWELL)
      ID1 = 0
      GO TO 8701
C
C                    PLOT TRUE DIP DIAGRAMS
C                    ==========================
 8759 CALL TDIDXX(J1STIM(20),NUWELL)
      ID1 = 0
      GO TO 8701
C
C                    PRINT AND PLOT PERSISTENT CORRELATIONS
C                    ======================================
C
 8761 CALL PERSXX(J1STIM(8),NUWELL)
      ID1 = 0
      GO TO 8701
C
C                    PRINT AND PLOT MARKERS IN A CROSS-SECTION
C                    =========================================
C
 8771 CALL TRACXX(J1STIM(8),NUWELL)
      ID1 = 0
      GO TO 8701
C
C                    DISPLAY PROPORTION OF SHALE IN A CROSS-SECTION
C                    ==============================================
C
 8781 CALL LITHOS(J1STIM(8),NUWELL)     ! 19
      ID1 = 0
      GO TO 8701
C
C                    DISPLAY THE POROSITY IN A CROSS-SECTION
C                    =======================================
C
 8791 CALL LPCFSE(J1STIM(8),NUWELL)     ! 22
      ID1 = 0
      GO TO 8701
C
C                    DISPLAY THE LITHOSTRATIGRAPHY IN A CROSS-SECTION
C                    ================================================
C
 8796 CALL LITH2(J1STIM(8),NUWELL)        ! 24
      ID1 = 0
      GO TO 8701
C
C**********************************************************************
C
C         ANALYSIS AND TRANSFORMATION
C
C**********************************************************************
C
 8901 CALL MENUAN(DATAFL,ID1,MENUS)
      IF (MENUS .EQ. 'WB') GO TO 8911
      IF ( DATAFL .GT. 0 ) THEN
         IF (MENUS .EQ. 'WS') GO TO 8921
         IF (MENUS .EQ. 'CB') GO TO 8925
         IF ( ID1 .GT. 0 ) THEN
           IF (MENUS .EQ. 'LS') GO TO 8931
           IF (MENUS .EQ. 'SE') GO TO 8941
           IF (MENUS .EQ. 'PL') GO TO 8951
           IF (MENUS .EQ. 'TL') GO TO 8531
           IF (MENUS .EQ. 'SL') GO TO 8541
           IF (MENUS .EQ. 'RT') GO TO 8551
           IF (MENUS .EQ. 'BL') GO TO 8561
         ENDIF
      ENDIF
      IF (MENUS .EQ. 'RE') GO TO 1
      GO TO 8901
C
C                    WELL DATA FILE SELECTION
C                    ========================
C
 8911 CALL DATAFS(DATAFL,NUWELL,ID1OLD,5)
      DO 8912 I = 1,J1STIN
      IF (I. EQ. 4   .OR.  I .EQ. 5) GO TO 8912
      J1STIM(I) = 0
 8912 CONTINUE
      GO TO 8901
C                    SELECTION OF WELLS
C                    ==================
C
 8921 CALL WELLXX(NUWELL)
      DO 8922 I = 1,I1STIN
      I1STIM(I) = 0
 8922 CONTINUE
      GO TO 8901
C                    SELECTION OF CORRELATION DATABASE
C                    =================================
C
 8925 CALL CORRXX
      GO TO 8901
C
C                    LOCAL SEMIVARIOGRAM
C                    ===================
 8931 CALL LOSEMI(I1STIM(13))
      GO TO 8901
C
C                    SEMIVARIOGRAM
C                    =============
C
 8941 CALL SEMIVA(I1STIM(14))
      GO TO 8901
C
C                    PLOT LOGS
C                    =========
C
 8951 CALL PLLOGS(I1STIM(2))
      GO TO 8901
C
C                    CLIP PEAKS
C                    ==========
C
 8531 CALL CLLOGS(I1STIM(1))
      GO TO 8901
C
C                    STANDARDIZE LOGS
C                    ================
C
 8541 IF ( I1STIM(3) .EQ. 0) THEN
         CALL STLOGS(I1STIM(3))
        ELSE
         CALL TXTCLR(ICOLOR(6))
         CALL GTEXTC(30,25,'***** LOGS HAVE ALREADY BEEN '//
     1                     'STANDARDIZED.')
         CALL GTEXTC(37,26,'RELOAD WELLS TO STANDARDIZE AGAIN.')
         CALL SCHOLD
      END IF
      GO TO 8901
C
C                    REMOVE LINEAR TREND FROM LOGS
C                    =============================
C
 8551 IF ( I1STIM(4) .EQ. 0) THEN
         CALL RTLOGS(I1STIM(4))
        ELSE
         CALL TXTCLR(ICOLOR(6))
         CALL GTEXTC(30,25,'***** TRENDS HAVE ALREADY BEEN REMOVED.')
         CALL GTEXTC(37,26,'SELECT WELLS TO REMOVE TRENDS AGAIN.')
         CALL SCHOLD
      END IF
      GO TO 8901
C
C                    CORRECTS SPONTANEOUS POTENTIAL BASE LINE
C                    ========================================
C
 8561 IF ( I1STIM(8) .EQ. 0) THEN
         CALL SPBALI(I1STIM(8))
        ELSE
         CALL TXTCLR(ICOLOR(6))
         CALL GTEXTC(30,19,
     1              '***** SELECT WELLS TO TRY THIS OPTION AGAIN.')
         ID2 = 0
         CALL SCHOLD
      END IF
      GO TO 8901
      END
